@@ -3,6 +3,7 @@
 //! This is not meant to be used as a crate!
 
 pub(crate) mod custom;
+pub(crate) mod demo;
 pub(crate) mod diff;
 pub(crate) mod execute;
 pub(crate) mod export;
@@ -20,7 +21,8 @@ pub(crate) mod tools;
 pub(crate) mod typst;
 
 pub use crate::{
-    custom::{Config, ImageProtocol},
+    custom::{Config, ImageProtocol, ValidateOverflows},
+    demo::ThemesDemo,
     export::{ExportError, Exporter},
     input::source::CommandSource,
     markdown::parse::MarkdownParser,
