@@ -4,10 +4,10 @@ use directories::ProjectDirs;
 use presenterm::{
     CommandSource, Config, Exporter, GraphicsMode, HighlightThemeSet, ImagePrinter, ImageProtocol, ImageRegistry,
     LoadThemeError, MarkdownParser, PresentMode, PresentationBuilderOptions, PresentationTheme, PresentationThemeSet,
-    Presenter, PresenterOptions, Resources, Themes, TypstRender,
+    Presenter, PresenterOptions, Resources, Themes, ThemesDemo, TypstRender, ValidateOverflows,
 };
 use std::{
-    env,
+    env, io,
     path::{Path, PathBuf},
     rc::Rc,
 };
@@ -35,7 +35,7 @@ struct Cli {
     #[clap(long, hide = true)]
     export: bool,
 
-    /// Whether to use presentation mode.
+    /// Use presentation mode.
     #[clap(short, long, default_value_t = false)]
     present: bool,
 
@@ -43,6 +43,10 @@ struct Cli {
     #[clap(short, long)]
     theme: Option<String>,
 
+    /// List all supported themes.
+    #[clap(long)]
+    list_themes: bool,
+
     /// Display acknowledgements.
     #[clap(long, group = "target")]
     acknowledgements: bool,
@@ -51,6 +55,10 @@ struct Cli {
     #[clap(long)]
     image_protocol: Option<ImageProtocol>,
 
+    /// Validate that the presentation does not overflow the terminal screen.
+    #[clap(long)]
+    validate_overflows: bool,
+
     /// The path to the configuration file.
     #[clap(short, long)]
     config_file: Option<String>,
@@ -145,6 +153,16 @@ fn select_graphics_mode(cli: &Cli, config: &Config) -> GraphicsMode {
     }
 }
 
+fn overflow_validation(mode: &PresentMode, config: &ValidateOverflows) -> bool {
+    match (config, mode) {
+        (ValidateOverflows::Always, _) => true,
+        (ValidateOverflows::Never, _) => false,
+        (ValidateOverflows::WhenPresenting, PresentMode::Presentation) => true,
+        (ValidateOverflows::WhenDeveloping, PresentMode::Development) => true,
+        _ => false,
+    }
+}
+
 fn run(mut cli: Cli) -> Result<(), Box<dyn std::error::Error>> {
     let (config, themes) = load_customizations(cli.config_file.clone().map(PathBuf::from))?;
 
@@ -160,11 +178,17 @@ fn run(mut cli: Cli) -> Result<(), Box<dyn std::error::Error>> {
     if cli.acknowledgements {
         display_acknowledgements();
         return Ok(());
+    } else if cli.list_themes {
+        let bindings = config.bindings.try_into()?;
+        let demo = ThemesDemo::new(themes, bindings, io::stdout())?;
+        demo.run()?;
+        return Ok(());
     }
 
     let path = cli.path.take().unwrap_or_else(|| {
         Cli::command().error(ErrorKind::MissingRequiredArgument, "no path specified").exit();
     });
+    let validate_overflows = overflow_validation(&mode, &config.defaults.validate_overflows) || cli.validate_overflows;
     let resources_path = path.parent().unwrap_or(Path::new("/"));
     let mut options = make_builder_options(&config, &mode, force_default_theme);
     let graphics_mode = select_graphics_mode(&cli, &config);
@@ -196,6 +220,7 @@ fn run(mut cli: Cli) -> Result<(), Box<dyn std::error::Error>> {
             mode,
             font_size_fallback: config.defaults.terminal_font_size,
             bindings: config.bindings,
+            validate_overflows,
         };
         let presenter = Presenter::new(&default_theme, commands, parser, resources, typst, themes, printer, options);
         presenter.present(&path)?;
