@@ -9,7 +9,8 @@ use crate::{
     processing::builder::{BuildError, PresentationBuilder, PresentationBuilderOptions, Themes},
     render::{
         draw::{RenderError, RenderResult, TerminalDrawer},
-        highlighting::CodeHighlighter,
+        properties::WindowSize,
+        validate::OverflowValidator,
     },
     resource::Resources,
     theme::PresentationTheme,
@@ -17,6 +18,7 @@ use crate::{
 };
 use std::{
     collections::HashSet,
+    fmt::Display,
     fs,
     io::{self, Stdout},
     mem,
@@ -29,6 +31,7 @@ pub struct PresenterOptions {
     pub builder_options: PresentationBuilderOptions,
     pub font_size_fallback: u8,
     pub bindings: KeyBindingsConfig,
+    pub validate_overflows: bool,
 }
 
 /// A slideshow presenter.
@@ -77,7 +80,7 @@ impl<'a> Presenter<'a> {
     /// Run a presentation.
     pub fn present(mut self, path: &Path) -> Result<(), PresentationError> {
         self.state = PresenterState::Presenting(Presentation::from(vec![]));
-        self.try_reload(path);
+        self.try_reload(path, true);
 
         let mut drawer =
             TerminalDrawer::new(io::stdout(), self.image_printer.clone(), self.options.font_size_fallback)?;
@@ -93,7 +96,7 @@ impl<'a> Presenter<'a> {
                 match self.apply_command(command) {
                     CommandSideEffect::Exit => return Ok(()),
                     CommandSideEffect::Reload => {
-                        self.try_reload(path);
+                        self.try_reload(path, false);
                         break;
                     }
                     CommandSideEffect::Redraw => {
@@ -155,6 +158,11 @@ impl<'a> Presenter<'a> {
             Command::Exit => return CommandSideEffect::Exit,
             _ => (),
         };
+        if matches!(command, Command::Redraw) {
+            let presentation = mem::take(&mut self.state).into_presentation();
+            self.state = self.validate_overflows(presentation);
+            return CommandSideEffect::Redraw;
+        }
 
         // Now apply the commands that require a presentation.
         let presentation = match &mut self.state {
@@ -166,7 +174,6 @@ impl<'a> Presenter<'a> {
             }
         };
         let needs_redraw = match command {
-            Command::Redraw => true,
             Command::Next => presentation.jump_next(),
             Command::Previous => presentation.jump_previous(),
             Command::FirstSlide => presentation.jump_first_slide(),
@@ -194,15 +201,15 @@ impl<'a> Presenter<'a> {
                 true
             }
             // These are handled above as they don't require the presentation
-            Command::Reload | Command::HardReload | Command::Exit => {
+            Command::Reload | Command::HardReload | Command::Exit | Command::Redraw => {
                 panic!("unreachable commands")
             }
         };
         if needs_redraw { CommandSideEffect::Redraw } else { CommandSideEffect::None }
     }
 
-    fn try_reload(&mut self, path: &Path) {
-        if matches!(self.options.mode, PresentMode::Presentation) {
+    fn try_reload(&mut self, path: &Path, force: bool) {
+        if matches!(self.options.mode, PresentMode::Presentation) && !force {
             return;
         }
         self.slides_with_pending_widgets.clear();
@@ -216,21 +223,35 @@ impl<'a> Presenter<'a> {
                     presentation.go_to_slide(current.current_slide_index());
                     presentation.jump_chunk(current.current_chunk());
                 }
-                self.state = PresenterState::Presenting(presentation)
+                self.state = self.validate_overflows(presentation);
             }
             Err(e) => {
                 let presentation = mem::take(&mut self.state).into_presentation();
-                self.state = PresenterState::Failure { error: e.to_string(), presentation }
+                self.state = PresenterState::failure(e, presentation);
             }
         };
     }
 
+    fn validate_overflows(&self, presentation: Presentation) -> PresenterState {
+        if self.options.validate_overflows {
+            let dimensions = match WindowSize::current(self.options.font_size_fallback) {
+                Ok(dimensions) => dimensions,
+                Err(e) => return PresenterState::failure(e, presentation),
+            };
+            match OverflowValidator::validate(&presentation, dimensions) {
+                Ok(()) => PresenterState::Presenting(presentation),
+                Err(e) => PresenterState::failure(e, presentation),
+            }
+        } else {
+            PresenterState::Presenting(presentation)
+        }
+    }
+
     fn load_presentation(&mut self, path: &Path) -> Result<Presentation, LoadPresentationError> {
         let content = fs::read_to_string(path).map_err(LoadPresentationError::Reading)?;
         let elements = self.parser.parse(&content)?;
         let export_mode = matches!(self.options.mode, PresentMode::Export);
         let mut presentation = PresentationBuilder::new(
-            CodeHighlighter::default(),
             self.default_theme,
             &mut self.resources,
             &mut self.typst,
@@ -292,6 +313,10 @@ enum PresenterState {
 }
 
 impl PresenterState {
+    pub(crate) fn failure<E: Display>(error: E, presentation: Presentation) -> Self {
+        PresenterState::Failure { error: error.to_string(), presentation }
+    }
+
     fn presentation(&self) -> &Presentation {
         match self {
             Self::Presenting(presentation)
