@@ -21,7 +21,7 @@ use crate::{
     },
     render::highlighting::{CodeHighlighter, HighlightThemeSet},
     resource::{LoadImageError, Resources},
-    style::{Color, TextStyle},
+    style::{Color, Colors, TextStyle},
     theme::{
         Alignment, AuthorPositioning, ElementType, LoadThemeError, Margin, PresentationTheme, PresentationThemeSet,
     },
@@ -110,7 +110,6 @@ impl<'a> PresentationBuilder<'a> {
     /// Construct a new builder.
     #[allow(clippy::too_many_arguments)]
     pub(crate) fn new(
-        default_highlighter: CodeHighlighter,
         default_theme: &'a PresentationTheme,
         resources: &'a mut Resources,
         typst: &'a mut TypstRender,
@@ -124,7 +123,7 @@ impl<'a> PresentationBuilder<'a> {
             chunk_operations: Vec::new(),
             chunk_mutators: Vec::new(),
             slides: Vec::new(),
-            highlighter: default_highlighter,
+            highlighter: CodeHighlighter::default(),
             theme: Cow::Borrowed(default_theme),
             resources,
             typst,
@@ -443,7 +442,17 @@ impl<'a> PresentationBuilder<'a> {
         }
 
         let style = self.theme.slide_title.clone();
-        text.apply_style(&TextStyle::default().bold().colors(style.colors.clone()));
+        let mut text_style = TextStyle::default().colors(style.colors.clone());
+        if style.bold {
+            text_style = text_style.bold();
+        }
+        if style.italics {
+            text_style = text_style.italics();
+        }
+        if style.underlined {
+            text_style = text_style.underlined();
+        }
+        text.apply_style(&text_style);
 
         for _ in 0..style.padding_top.unwrap_or(0) {
             self.push_line_break();
@@ -587,19 +596,31 @@ impl<'a> PresentationBuilder<'a> {
 
     fn push_block_quote(&mut self, lines: Vec<String>) {
         let prefix = self.theme.block_quote.prefix.clone().unwrap_or_default();
-        let block_length = lines.iter().map(|line| line.width() + prefix.width()).max().unwrap_or(0);
+        let block_length = lines.iter().map(|line| line.width() + prefix.width()).max().unwrap_or(0) as u16;
+        let prefix_color = self.theme.block_quote.colors.prefix.or(self.theme.block_quote.colors.base.foreground);
+        let prefix = Text::new(
+            prefix,
+            TextStyle::default()
+                .colors(Colors { foreground: prefix_color, background: self.theme.block_quote.colors.base.background }),
+        );
+        let alignment = self.theme.alignment(&ElementType::BlockQuote).clone();
+        let style = TextStyle::default().colors(self.theme.block_quote.colors.base.clone());
 
-        self.chunk_operations.push(RenderOperation::SetColors(self.theme.block_quote.colors.clone()));
-        for mut line in lines {
-            line.insert_str(0, &prefix);
-
-            let line_length = line.width();
-            self.chunk_operations.push(RenderOperation::RenderPreformattedLine(PreformattedLine {
-                text: line,
-                unformatted_length: line_length,
-                block_length,
-                alignment: self.theme.alignment(&ElementType::BlockQuote).clone(),
-            }));
+        for line in lines {
+            let line = TextBlock(vec![prefix.clone(), Text::new(line, style.clone())]);
+            self.chunk_operations.extend([
+                // Print a preformatted empty block so we fill in the line with properly colored
+                // spaces.
+                RenderOperation::SetColors(self.theme.block_quote.colors.base.clone()),
+                RenderOperation::RenderPreformattedLine(PreformattedLine {
+                    text: "".into(),
+                    unformatted_length: 0,
+                    block_length,
+                    alignment: alignment.clone(),
+                }),
+                // Now render our prefix + entire line
+                RenderOperation::RenderText { line: line.into(), alignment: alignment.clone() },
+            ]);
             self.push_line_break();
         }
         self.chunk_operations.push(RenderOperation::SetColors(self.theme.default_style.colors.clone()));
@@ -677,9 +698,10 @@ impl<'a> PresentationBuilder<'a> {
         }));
 
         let mut output = Vec::new();
+        let block_style = &self.theme.code;
         for line in lines.into_iter() {
-            let highlighted = line.highlight(&padding_style, &mut code_highlighter);
-            let not_highlighted = line.highlight(&padding_style, &mut empty_highlighter);
+            let highlighted = line.highlight(&padding_style, &mut code_highlighter, block_style);
+            let not_highlighted = line.highlight(&padding_style, &mut empty_highlighter, block_style);
             let width = line.width();
             let line_number = line.line_number;
             let context = context.clone();
@@ -999,14 +1021,12 @@ mod test {
         elements: Vec<MarkdownElement>,
         options: PresentationBuilderOptions,
     ) -> Result<Presentation, BuildError> {
-        let highlighter = CodeHighlighter::default();
         let theme = PresentationTheme::default();
         let mut resources = Resources::new("/tmp", Default::default());
         let mut typst = TypstRender::default();
         let themes = Themes::default();
         let bindings = KeyBindingsConfig::default();
         let builder = PresentationBuilder::new(
-            highlighter,
             &theme,
             &mut resources,
             &mut typst,
