@@ -1,4 +1,7 @@
-use super::{engine::RenderEngine, terminal::Terminal};
+use super::{
+    engine::RenderEngine,
+    terminal::{Terminal, TerminalWrite},
+};
 use crate::{
     markdown::{elements::Text, text::WeightedTextBlock},
     media::printer::{ImagePrinter, PrintImageError},
@@ -13,14 +16,14 @@ use std::{io, rc::Rc};
 pub(crate) type RenderResult = Result<(), RenderError>;
 
 /// Allows drawing elements in the terminal.
-pub(crate) struct TerminalDrawer<W: io::Write> {
+pub(crate) struct TerminalDrawer<W: TerminalWrite> {
     terminal: Terminal<W>,
     font_size_fallback: u8,
 }
 
 impl<W> TerminalDrawer<W>
 where
-    W: io::Write,
+    W: TerminalWrite,
 {
     /// Construct a drawer over a [std::io::Write].
     pub(crate) fn new(handle: W, image_printer: Rc<ImagePrinter>, font_size_fallback: u8) -> io::Result<Self> {
@@ -44,11 +47,11 @@ where
 
         let alignment = Alignment::Center { minimum_size: 0, minimum_margin: Margin::Percent(8) };
         let mut operations = vec![
-            RenderOperation::ClearScreen,
             RenderOperation::SetColors(Colors {
                 foreground: Some(Color::new(255, 0, 0)),
                 background: Some(Color::new(0, 0, 0)),
             }),
+            RenderOperation::ClearScreen,
             RenderOperation::JumpToVerticalCenter,
             RenderOperation::RenderText { line: WeightedTextBlock::from(heading), alignment: alignment.clone() },
             RenderOperation::RenderLineBreak,
@@ -79,7 +82,8 @@ where
     }
 
     fn create_engine(&mut self, dimensions: WindowSize) -> RenderEngine<W> {
-        RenderEngine::new(&mut self.terminal, dimensions)
+        let options = Default::default();
+        RenderEngine::new(&mut self.terminal, dimensions, options)
     }
 }
 
@@ -104,6 +108,12 @@ pub enum RenderError {
     #[error("printing image: {0}")]
     PrintImage(#[from] PrintImageError),
 
+    #[error("horizontal overflow")]
+    HorizontalOverflow,
+
+    #[error("vertical overflow")]
+    VerticalOverflow,
+
     #[error(transparent)]
     Other(Box<dyn std::error::Error>),
 }
